@@ -285,26 +285,8 @@ def record_rosbag(topics_file, rosbag_file_name, source, delete_rosbag):
         print("Recording stopped")
 
         # send rosbag file through api
-        with open(rosbag_file_name, 'rb') as f:
-            files = {'file': f}
-            response = requests.post(f"{base_url}/datasets/uploadBag", files=files)
-            if response.status_code == 200:
-                response_data = response.json()
-                click.echo(f"Message: {response_data['message']}.")
-
-                for inserted in response_data['inserted_objects']:
-                    response = requests.put(
-                        f"{base_url}/datasets/{inserted[1]}", 
-                        json={"Source": source}
-                    )
-                    if response.status_code == 200:
-                        click.echo("Dataset updated successfully")
-                        
-            elif response.status_code == 400:
-                click.echo(f"Error: {response.json()['error']}")
-            else:
-                click.echo(f"Failed to upload the file. Status code: {response.status_code}")
-
+        upload_bag(rosbag_file_name, source)
+       
         if delete_rosbag:
             print("Removing rosbag file")
             subprocess.run(f"rm {rosbag_file_name}", shell=True)
